use std::borrow::Borrow;
use std::sync::mpsc::Sender;
use std::time::Duration;
use crate::patterns::patterns;
use crate::Strip;

struct Context<const N: usize> {
    pattern : Box<dyn Iterator<Item = Strip<N>>>,
    period: Duration,
}

struct Runner<const N: usize> {
    list : Vec<Context<N>>,
}

impl<const N: usize> Runner<N> {
   async fn runner_loop(self, tx: Sender<Strip<N>>) {
        for mut context in self.list {
            let mut strip = context.pattern.next().unwrap();
            let delay = context.period;
            while tx.send(strip).is_ok() {
                if let Some(value) = context.pattern.next() {
                    strip = value;
                } else {
                    break;
                }
                tokio::time::sleep(delay).await;
            }
        }
    }
}
